<?php
/*
 *  Plugin Name: Dialogfeed
 *  Plugin URI:
 *  Description: Allow to take the flow from your widget dialogfeed.
 *  Author: Dialog Solutions
 *  Version: 1.0
 *  Author URI: http://www.dialogfeed.com/en/
 */

if(!class_exists('Dialogfeed')) {

  class Dialogfeed {

    /*
     * Initializes plugin (launches all initializing treatments)
     */
    public static function init() {
      self::add_actions();
      self::register_shortcodes();
    }


    /*
     * Registers every needed action
     */
    private static function add_actions() {
      add_action('init', array(__CLASS__, 'load_textdomain'));

      if(is_admin()) {
        // BO Actions
        add_action('admin_menu', array(__CLASS__, 'add_pages_in_menu'));
      } else {
        // FO Actions
      }
    }

    /*
     * Add menu items
     */
    public static function add_pages_in_menu() {
      add_menu_page(
        'Dialogfeed', // page title
        'Dialogfeed', // menu title
        'read',       // required capability
        'dialogfeed', // menu slug
        array('Dialogfeed', 'display_home_page' ), // displaying function
        ''            // icon
      );
    }

    /*
     * Loads the plugin's textdomain for translations
     */
    public static function load_textdomain() {
      load_plugin_textdomain('dialogfeed', false, dirname(plugin_basename( __FILE__ )).'/languages/');
    }

    /*
     * Displays the BO page
     */
    public static function display_home_page() {
      wp_enqueue_style("dialogfeed", plugins_url('css/dialogfeed.css', __FILE__));
      include('views/backend.php');
    }

    /*************
     *           *
     * SHORTCODE *
     *           *
     ************/

    /*
     * Gets the wall shortcode's attributes and display the wall
     */
    public function display_wall($atts) {
      extract(shortcode_atts(array(
        "slug"   => "dialogfeed_wall",
        "width"  => "90%",
        "height" => "750"
      ), $atts));

      wp_enqueue_style("dialogfeed", plugins_url('css/dialogfeed.css', __FILE__));

      ob_start();
      include('views/widgets/wall.php');
      $out = ob_get_contents();
      ob_end_clean();
      return $out;
    }

    /*
     * Registers our different shortcodes into wordpress engine
     */
    private static function register_shortcodes() {
      add_shortcode('dialogfeed_wall', array(__CLASS__, 'display_wall'));
    }

  } // END Dialogfeed Class

  Dialogfeed::init();
} // END if(!class_exists('Dialogfeed'))
